==========================
Create Plone addon package
==========================

With this template you can create a basic Plone package.

.. code-block:: sh

    mrbob -O collective.todos bobtemplates.plone:addon

This will create a Python package for you which you can extend manually or by using other subtemplates like ``theme`` or ``content_type`` from bobtemplates.plone.

